@@ -8,12 +8,9 @@ import json
 import networkx as nx
 from pathlib import Path
 from io import IOBase
-from typing import Union
-
-from pelote.types import GraphologySerializedGraph, AnyGraph, FileHandle
 
 
-def parse_graphology_json(data: GraphologySerializedGraph) -> AnyGraph:
+def parse_graphology_json(data):
     if "options" not in data:
         raise TypeError(
             "cannot parse a graphology json that does not record the graph options"
@@ -22,6 +19,7 @@ def parse_graphology_json(data: GraphologySerializedGraph) -> AnyGraph:
     options = data["options"]
     graph_type = options["type"]
 
+    graph_attributes = data.get("attributes", {})
     nodes = data.get("nodes")
     edges = data.get("edges")
     must_check_mixed = graph_type == "mixed"
@@ -34,18 +32,16 @@ def parse_graphology_json(data: GraphologySerializedGraph) -> AnyGraph:
 
     is_multi = options["multi"]
 
-    graph: AnyGraph
-
     if graph_type == "directed":
         if is_multi:
-            graph = nx.MultiDiGraph()
+            graph = nx.MultiDiGraph(**graph_attributes)
         else:
-            graph = nx.DiGraph()
+            graph = nx.DiGraph(**graph_attributes)
     else:
         if is_multi:
-            graph = nx.MultiGraph()
+            graph = nx.MultiGraph(**graph_attributes)
         else:
-            graph = nx.Graph()
+            graph = nx.Graph(**graph_attributes)
 
     if nodes is not None:
         for serialized_node in nodes:
@@ -75,9 +71,7 @@ def parse_graphology_json(data: GraphologySerializedGraph) -> AnyGraph:
     return graph
 
 
-def read_graphology_json(
-    target: Union[FileHandle, GraphologySerializedGraph]
-) -> AnyGraph:
+def read_graphology_json(target):
     """
     Function reading and parsing the given json file representing a serialized
     [graphology](https://graphology.github.io/) graph as a networkx graph.
@@ -93,8 +87,6 @@ def read_graphology_json(
     Returns:
         nx.AnyGraph: a networkx graph instance.
     """
-    data: GraphologySerializedGraph
-
     if isinstance(target, (str, Path)):
         with open(target) as f:
             data = json.load(f)
