@@ -2,11 +2,36 @@
 # Pelote Multiscale Backbone
 # =============================================================================
 #
-from pelote.graph import filter_edges, check_graph
 from pelote.metrics import edge_disparity
+from pelote.sparsification.utils import Sparsifier
 
 
-def multiscale_backbone(graph, alpha: float = 0.05, edge_weight_attr: str = "weight"):
+class MultiscaleBackboneSparsifier(Sparsifier):
+    def __init__(
+        self,
+        alpha: float = 0.05,
+        edge_weight_attr: str = "weight",
+        keep_connected: bool = False,
+    ):
+        def edge_predicate_factory(graph):
+            disparity = edge_disparity(graph, edge_weight_attr=edge_weight_attr)
+
+            def predicate(u, v, a):
+                return disparity[(u, v)] <= alpha
+
+            return predicate
+
+        super().__init__(
+            edge_predicate_factory=edge_predicate_factory, keep_connected=keep_connected
+        )
+
+
+def multiscale_backbone(
+    graph,
+    alpha: float = 0.05,
+    edge_weight_attr: str = "weight",
+    keep_connected: bool = False,
+):
     """
     Function returning the multiscale backbone of the given graph, i.e. a copy
     of the graph were we only kept "relevant" edges, as defined by a
@@ -29,22 +54,12 @@ def multiscale_backbone(graph, alpha: float = 0.05, edge_weight_attr: str = "wei
             kept in the resulting graph. Defaults to 0.05.
         edge_weight_attr (str, optional): name of the edge attribute holding
             the edge's weight. Defaults to "weight".
+        keep_connected (bool, optional): whether to keep the graph connected
+            as it is using the UMST method. Defaults to False.
 
     Returns:
         nx.AnyGraph: the sparse graph.
     """
-    check_graph(graph)
-
-    # TODO: check directedness and constant weights
-
-    disparity = edge_disparity(graph, edge_weight_attr=edge_weight_attr)
-
-    def edge_predicate(u, v, a):
-        # NOTE: swapping because we have the guarantee the graph is undirected
-        # and the edge keys are arranged with lower node first
-        if u > v:
-            u, v = v, u
-
-        return disparity[(u, v)] <= alpha
-
-    return filter_edges(graph, edge_predicate)
+    return MultiscaleBackboneSparsifier(
+        alpha=alpha, edge_weight_attr=edge_weight_attr, keep_connected=keep_connected
+    )(graph)
